#!/usr/bin/env python 
# coding=utf-8
# @Time : 2020/7/13 0013 10:11 
# @Author : HL 
# @Site :  
# @File : DatabaseSpiderman.py 
# @Software: PyCharm
import difflib
import hashlib
import os
import re
import string
import time
import zipfile
from time import sleep

import pymysql
import requests
import xlrd
from bs4 import BeautifulSoup
from selenium import webdriver
from selenium.webdriver import Chrome, DesiredCapabilities

requests.packages.urllib3.disable_warnings()


class database():
    host_1 = '192.168.0.170'
    user_1 = 'skoda_community'
    password_1 = 'skoda_community'
    database_1 = 'skoda_community_ad'

    # host = 'localhost'
    # user = 'root'
    # password = 'root1226'
    host = '192.168.0.210'
    user = 'search_user'
    password = 'search_user'
    database = 'gmcms2_dev_statistic'
    # database = 'gmcms2_test'
    # host = 'rm-uf6te34unl5694f23.mysql.rds.aliyuncs.com'
    # user = 'contentdbuser'
    # password = '3D7RVMn3WR3n'
    # database = 'gmcms_2'
    port = 3306
    charset = 'utf8mb4'
    cursor = ''
    connet = ''
    CRAWL_TIME = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
    ipidea_api = "http://tiqu.linksocket.com:81/abroad?num={}&type=2&lb=1&sb=0&flow=1&regions=china&port=1&n=1"

    def __init__(self, default_db=0, api=ipidea_api):
        # 连接数据库
        self.ded = default_db
        if default_db:
            self.connet = pymysql.connect(host=self.host_1, user=self.user_1, password=self.password_1,
                                          database=self.database_1,
                                          port=self.port, charset=self.charset)
            self.cursor = self.connet.cursor()
        else:
            self.connet = pymysql.connect(host=self.host, user=self.user, password=self.password,
                                          database=self.database,
                                          port=self.port, charset=self.charset)
            self.cursor = self.connet.cursor()
        self.header = {
            'cookie': 'CNZZDATA1598548=cnzz_eid%3D1204699512-1598319345-http%253A%252F%252Fwww.cnena.com%252F%26ntime%3D1599530632; Hm_lvt_d0e33fc3fbfc66c95d9fdcc4c93a8288=1602730848,1604557864; __cfduid=df806d3b82b36b9279f6a819fbb6c6ef01612749813; srcurl=687474703a2f2f7777772e636e656e612e636f6d2f73686f77726f6f6d2f62656e63616e64792d68746d2d6669642d362d69642d33373637382e68746d6c; __51cke__=; USR=xvay6cmy%090%091615171397%09http%3A%2F%2Fwww.cnena.com%2Fshowroom%2Fbencandy.php%3FRurl%3Dfid-6-id-37678.html; __tins__2844959=%7B%22sid%22%3A%201615171062858%2C%20%22vd%22%3A%202%2C%20%22expires%22%3A%201615173198061%7D; __51laig__=2; security_session_verify=18616d097122eef5d7e23a3f881c7d0a; security_session_mid_verify=0b0cdb554e89f2850f9bdf92eb0b761c',
            'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.92 Safari/537.36'}
        self.api = api
        self.iplst = self.getIps(self.api)
        # # 代理服务器
        # self.proxyHost = "http-dyn.abuyun.com"
        # self.proxyPort = "9020"
        #
        # # 代理隧道验证信息
        # self.proxyUser = "H9XK0330X97147TD"
        # self.proxyPass = "3280B770F047D45B"

    # 插入
    def insertSql(self, sql):
        try:
            self.cursor.execute(sql)
            self.connet.commit()
        except Exception as e:
            print(e.args)
            if self.ded:
                self.connet = pymysql.connect(host=self.host_1, user=self.user_1, password=self.password_1,
                                              database=self.database_1,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            else:
                self.connet = pymysql.connect(host=self.host, user=self.user, password=self.password,
                                              database=self.database,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            try:
                self.cursor.execute(sql)
                self.connet.commit()
            except Exception as e1:
                print(e1.args)
                return False
        return True

    # 查询
    def selectBySql(self, sql):
        try:
            self.cursor.execute(sql)
            result = self.cursor.fetchall()
            return result
        except Exception as e:
            print(e.args)
            if self.ded:
                self.connet = pymysql.connect(host=self.host_1, user=self.user_1, password=self.password_1,
                                              database=self.database_1,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            else:
                self.connet = pymysql.connect(host=self.host, user=self.user, password=self.password,
                                              database=self.database,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            self.cursor.execute(sql)
            result = self.cursor.fetchall()
            return result

    # 验证是否存在
    def is_exist_sql(self, sql):
        try:
            self.cursor.execute(sql)
            if self.cursor.fetchone() is None:
                return False
            return True
        except Exception as e:
            print(e.args)
            if self.ded:
                self.connet = pymysql.connect(host=self.host_1, user=self.user_1, password=self.password_1,
                                              database=self.database_1,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            else:
                self.connet = pymysql.connect(host=self.host, user=self.user, password=self.password,
                                              database=self.database,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            self.cursor.execute(sql)
            if self.cursor.fetchone() is None:
                return False
            return True

    # 更新
    def updateTables(self, sql):
        try:
            self.cursor.execute(sql)
            self.connet.commit()
        except Exception as e:
            print(e.args)
            if self.ded:
                self.connet = pymysql.connect(host=self.host_1, user=self.user_1, password=self.password_1,
                                              database=self.database_1,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            else:
                self.connet = pymysql.connect(host=self.host, user=self.user, password=self.password,
                                              database=self.database,
                                              port=self.port, charset=self.charset)
                self.cursor = self.connet.cursor()
            self.cursor.execute(sql)
            self.connet.commit()

    # 根据字典，表名生成插入sql
    def sqlByDict(self, tablename, dics, **kwargs):
        conditon = ''
        values = ''
        for k, v in dict.items(dics):
            conditon = conditon + ',' + pymysql.escape_string(str(k))
            values = values + ',"' + pymysql.escape_string(str(v)) + '"'
        for k, v in dict.items(kwargs):
            conditon = conditon + ',' + pymysql.escape_string(str(k))
            values = values + ',"{}"'.format(pymysql.escape_string(str(v)))

        sql = "INSERT INTO `{}`({}) VALUES ({})".format(tablename, conditon[1:], values[1:])
        return sql

    # 读取Excel表格
    def readExcel(self, excel_path, sheetname):
        wb = xlrd.open_workbook(excel_path)
        sheet = wb.sheet_by_name(sheetname)
        return sheet

    # 获取页面源码
    def getHtml(self, href, encoding='utf-8', header={}):
        if header:
            res = requests.get(href, headers=header, verify=False)
            while res.status_code != 200:
                print('{} ========================= {}'.format(href, res.status_code))
                sleep(1.5)
                res = requests.get(href, headers=header, verify=False)
            res.encoding = encoding
        else:
            res = requests.get(href, headers=self.header, verify=False)
            while res.status_code != 200:
                print('{} ========================= {}'.format(href, res.status_code))
                sleep(1.5)
                res = requests.get(href, headers=self.header, verify=False)
            res.encoding = encoding
        return res.text

    # 获取链接Response
    def getResp(self, href, encoding='utf-8', header={}):
        if header:
            res = requests.get(href, headers=header, verify=False)
            while res.status_code != 200:
                print('{} ========================= {}'.format(href, res.status_code))
                sleep(1.5)
                res = requests.get(href, headers=header, verify=False)
            res.encoding = encoding
        else:
            res = requests.get(href, headers=self.header, verify=False)
            while res.status_code != 200:
                print('{} ========================= {}'.format(href, res.status_code))
                sleep(1.5)
                res = requests.get(href, headers=self.header, verify=False)
            res.encoding = encoding
        return res

    # 获取链接Response
    def getRespAby(self, href, encoding='utf-8', header={}):
        proxyMeta = "http://{}".format(self.iplst[0])
        proxies = {
            "http": proxyMeta,
            "https": proxyMeta,
        }
        if header == {}:
            headers = self.header
        else:
            headers = header
        num = 0
        exct = 0
        while True:
            if num > 10:
                return ''
            try:
                res = requests.get(href, headers=headers, proxies=proxies, verify=False, timeout=(10, 5))
                if res.status_code == 404:
                    print("{}  链接错误！！！ CODE：{}".format(href, res.status_code))
                    break
                while res.status_code != 200:
                    if exct > 5:
                        break
                    sleep(1.5)
                    print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                    exct += 1
                    res = requests.get(href, headers=headers, proxies=proxies, verify=False, timeout=(10, 5))
                break
            except requests.exceptions.ProxyError as pe:
                while True:
                    print('代理IP失效，重新获取代理IP！！！')
                    print(pe.args)
                    self.iplst = self.getIps(self.api)
                    proxyMeta = "http://{}".format(self.iplst[0])
                    proxies = {
                        "http": proxyMeta,
                        "https": proxyMeta,
                    }
                    try:
                        res = requests.get(href, headers=headers, proxies=proxies, verify=False, timeout=(10, 5))
                        if res.status_code == 404:
                            print("{}  链接错误！！！ CODE：{}".format(href, res.status_code))
                            break
                        while res.status_code != 200:
                            if exct > 5:
                                break
                            sleep(1.5)
                            print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                            exct += 1
                            res = requests.get(href, headers=headers, proxies=proxies, verify=False, timeout=(10, 5))
                    except requests.exceptions.ProxyError as pe:
                        pass
                    except Exception as e:
                        print(e.args)
                        print('{} 请求失败！！！'.format(href))
                    break
            except Exception as e:
                print(e.args)
                print('{} 请求失败！！！'.format(href))
                num += 1
        if res.status_code == 200:
            res.encoding = encoding
            return res
        return ""

    # 获取页面源码并返回BeautifulSoup
    def getSoup(self, href, headers={}, encoding='utf-8'):
        html = self.getHtml(href, encoding=encoding, header=headers)
        return BeautifulSoup(html, 'html.parser')

    def getIps(self, url, num=1):
        href = url.format(num)
        res = requests.get(href)
        jjson = res.json()
        data = jjson['data']
        while 1:
            if len(data):
                data_list = []
                for d in data:
                    ip = d['ip']
                    port = d['port']
                    data_list.append(ip + ':' + str(port))
                return data_list
            else:
                print('{} 没有获取到隧道IP！！！'.format(href))
                print(data)
                print(href)
                sleep(1.5)

    # 获取页面源码(加入代理) ipidea代理
    def getHtmlAby(self, href, encoding='utf-8', header={}):
        if header == {}:
            header = self.header

        #     proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
        #         "host": self.proxyHost,
        #         "port": self.proxyPort,
        #         "user": self.proxyUser,
        #         "pass": self.proxyPass,
        #     }
        # print(self.iplst[0])
        # proxyMeta = "http://{}".format('113.31.114.1902:11653')
        proxyMeta = "http://{}".format(self.iplst[0])

        proxies = {
            "http": proxyMeta,
            "https": proxyMeta,
        }
        num = 1
        while True:
            if num > 10:
                return ''
            try:
                res = requests.get(href, headers=header, proxies=proxies, verify=False, timeout=(10, 5))
                while res.status_code != 200:
                    sleep(1.5)
                    print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                    res = requests.get(href, headers=header, proxies=proxies, verify=False, timeout=(10, 5))
                break
            except requests.exceptions.ProxyError as pe:
                while True:
                    print('代理IP失效，重新获取代理IP！！！')
                    print(pe.args)
                    self.iplst = self.getIps(self.api)
                    proxyMeta = "http://{}".format(self.iplst[0])
                    proxies = {
                        "http": proxyMeta,
                        "https": proxyMeta,
                    }
                    try:
                        res = requests.get(href, headers=header, proxies=proxies, verify=False, timeout=(10, 5))
                        while res.status_code != 200:
                            sleep(1.5)
                            print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                            res = requests.get(href, headers=header, proxies=proxies, verify=False, timeout=(10, 5))
                    except requests.exceptions.ProxyError as pe:
                        pass
                    except Exception as e:
                        print(e.args)
                        print('{} 请求失败！！！'.format(href))
                    break
            except Exception as e:
                print(e.args)
                print('{} 请求失败！！！'.format(href))
                num += 1
        res.encoding = encoding
        return res.text

    # 获取页面源码并返回BeautifulSoup(加入代理)
    def getSoupAby(self, href, encoding='utf-8', headers={}):
        html = self.getHtmlAby(href, encoding, header=headers)
        return BeautifulSoup(html, 'html.parser')

    # 获取页面源码（post请求）
    def getHtmlPost(self, href, data, header={}):
        if header == {}:
            header = self.header
        while True:
            try:
                res = requests.post(href, headers=header, data=data, verify=False)
                while res.status_code != 200:
                    sleep(1.5)
                    print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                    res = requests.post(href, headers=header, data=data, verify=False)
                break
            except Exception as e:
                print(e.args)
                print('{} 请求失败！！！'.format(href))
        return res.text

    # 获取页面源码（post请求、加入代理）
    def getHtmlAbyPost(self, href, data, header={}):
        if header == {}:
            header = self.header
        # proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
        #     "host": self.proxyHost,
        #     "port": self.proxyPort,
        #     "user": self.proxyUser,
        #     "pass": self.proxyPass,
        # }
        proxyMeta = "http://{}".format(self.iplst[0])
        proxies = {
            "http": proxyMeta,
            "https": proxyMeta,
        }
        while True:
            try:
                res = requests.post(href, headers=header, data=data, proxies=proxies, verify=False)
                while res.status_code != 200:
                    sleep(1.5)
                    print("{}  请求异常！！！ CODE：{}".format(href, res.status_code))
                    res = requests.post(href, headers=header, data=data, proxies=proxies, verify=False)
                break
            except requests.exceptions.ProxyError as pe:
                print('代理IP失效，重新获取代理IP！！！')
                print(pe.args)
                self.iplst = self.getIps(self.api)
                proxyMeta = "http://{}".format(self.iplst[0])
                proxies = {
                    "http": proxyMeta,
                    "https": proxyMeta,
                }
            except Exception as e:
                print(e.args)
                print('{} 请求失败！！！'.format(href))
        return res.text

    # 将字符串生成MD5
    def getMD5(self, str):
        m = hashlib.md5()
        m.update(str.encode("utf8"))
        return m.hexdigest()

    # 比较两字符串的相似度
    def string_similar(self, s1, s2):
        try:
            f = difflib.SequenceMatcher(None, s1, s2).quick_ratio()
        except Exception as e:
            print(e.args)
            print(s1)
            print(s2)
            f = 0
        return f

    # 上传图片到Zimg（传入图片链接，和下载图片暂存的本机路径）
    def uploadZimg(self, url, zimgUrl, path):
        if not os.path.exists(path):
            try:
                r = requests.get(url, verify=False)
                r.raise_for_status()
                # 使用with语句可以不用自己手动关闭已经打开的文件流
                with open(path, "wb") as f:  # 开始写文件，wb代表写二进制文件
                    f.write(r.content)
            except Exception as e:
                print("爬取失败:" + str(e))
                return ''
        header = {'Connection': 'Keep-Alive',
                  'Cache-Control': 'no-cache',
                  }

        files = {'files': open(path, 'rb')}
        n = 1
        while True:
            try:
                r = requests.post(zimgUrl, files=files, headers=header)
                if 'Image upload successfully' in r.text:
                    md5 = re.search('<h1>MD5:(.*?)</h1>', r.text).group(1)
                    return md5
                else:
                    print('上传失败！！！')
                    return ''
            except Exception as e:
                print('上传失败：' + str(e))
                if n > 4:
                    return ''
                n += 1
                sleep(1.5)

    # webdriver+selenium 模拟浏览器
    def getDriver(self):
        # proxy_auth_plugin_path = self.create_proxy_auth_extension(
        #     proxy_host=self.proxyHost,
        #     proxy_port=self.proxyPort,
        #     proxy_username=self.proxyUser,
        #     proxy_password=self.proxyPass)

        option = webdriver.ChromeOptions()

        # option.add_argument("--start-maximized")
        # prefs = {'profile.managed_default_content_settings.images': 2}
        # option.add_experimental_option('prefs', prefs)
        option.add_experimental_option('excludeSwitches', ['enable-automation'])
        # option.add_extension(proxy_auth_plugin_path)

        driver = webdriver.Chrome(chrome_options=option, executable_path="D:\\chromedriver.exe")
        return driver

    # webdriver+selenium 模拟手机浏览器
    def getWapDriver(self):
        proxy_auth_plugin_path = self.create_proxy_auth_extension(
            proxy_host=self.proxyHost,
            proxy_port=self.proxyPort,
            proxy_username=self.proxyUser,
            proxy_password=self.proxyPass)

        option = webdriver.ChromeOptions()
        # wap端
        mobileEmulation = {'deviceName': 'iPhone X'}
        option.add_experimental_option('mobileEmulation', mobileEmulation)
        # 最大化
        # option.add_argument("--start-maximized")
        # 不加载图片
        prefs = {'profile.managed_default_content_settings.images': 2}
        option.add_experimental_option('prefs', prefs)
        # 防爬检测
        option.add_experimental_option('excludeSwitches', ['enable-automation'])
        option.add_extension(proxy_auth_plugin_path)

        driver = webdriver.Chrome(chrome_options=option)
        return driver

    def getPhatomjsDriver(self, headers={}):
        if headers == {}:
            headers = self.header
        # 初始化浏览器对象
        # 使用copy() 防止修改原代码定义dict
        cap = DesiredCapabilities.PHANTOMJS.copy()
        for key, value in headers.items():
            cap['phantomjs.page.customHeaders.{}'.format(
                key)] = value

        # 在初始化浏览器对象的时候可以接收一个service_args的参数，使用这个参数设置代理
        driver = webdriver.PhantomJS(desired_capabilities=cap)

        # 设置页面加载和js加载超时时间，超时立即报错，如下设置超时时间为10秒
        driver.set_page_load_timeout(25)
        driver.set_script_timeout(25)

        return driver

    def getPhatomjsProxyDriver(self, headers={}):
        if headers == {}:
            headers = self.header
        # 初始化浏览器对象
        # 使用copy() 防止修改原代码定义dict
        cap = DesiredCapabilities.PHANTOMJS.copy()
        for key, value in headers.items():
            cap['phantomjs.page.customHeaders.{}'.format(
                key)] = value
        proxy = [
            '--proxy=%s:%s' % (self.proxyHost, self.proxyPort),  # 代理服务器的域名
            '--proxy-type=http',  # 代理类型
            '--proxy-auth=%s:%s' % (self.proxyUser, self.proxyPass),  # 代理验证所需的用户名和密码
            '--ignore-ssl-errors=true',  # 忽略https错误
        ]

        # 在初始化浏览器对象的时候可以接收一个service_args的参数，使用这个参数设置代理
        driver = webdriver.PhantomJS(service_args=proxy, desired_capabilities=cap)

        # 设置页面加载和js加载超时时间，超时立即报错，如下设置超时时间为10秒
        driver.set_page_load_timeout(25)
        driver.set_script_timeout(25)

        return driver

    # 加入代理工具方法
    def create_proxy_auth_extension(self, proxy_host, proxy_port,
                                    proxy_username, proxy_password,
                                    scheme='http', plugin_path=None):
        if plugin_path is None:
            plugin_path = 'D:/{}_{}@http-dyn.abuyun.com_9020.zip'.format(proxy_username, proxy_password)

        manifest_json = """
        {
            "version": "1.0.0",
            "manifest_version": 2,
            "name": "Abuyun Proxy",
            "permissions": [
                "proxy",
                "tabs",
                "unlimitedStorage",
                "storage",
                "<all_urls>",
                "webRequest",
                "webRequestBlocking"
            ],
            "background": {
                "scripts": ["background.js"]
            },
            "minimum_chrome_version":"22.0.0"
        }
        """

        background_js = string.Template(
            """
            var config = {
                mode: "fixed_servers",
                rules: {
                    singleProxy: {
                        scheme: "${scheme}",
                        host: "${host}",
                        port: parseInt(${port})
                    },
                    bypassList: ["foobar.com"]
                }
              };

            chrome.proxy.settings.set({value: config, scope: "regular"}, function() {});

            function callbackFn(details) {
                return {
                    authCredentials: {
                        username: "${username}",
                        password: "${password}"
                    }
                };
            }

            chrome.webRequest.onAuthRequired.addListener(
                callbackFn,
                {urls: ["<all_urls>"]},
                ['blocking']
            );
            """
        ).substitute(
            host=proxy_host,
            port=proxy_port,
            username=proxy_username,
            password=proxy_password,
            scheme=scheme,
        )

        with zipfile.ZipFile(plugin_path, 'w') as zp:
            zp.writestr("manifest.json", manifest_json)
            zp.writestr("background.js", background_js)

        return plugin_path

# if __name__ == '__main__':
#     database().getIps()



# -*- coding: utf-8 -*-
import sys


class ProcessInformation():
    def __init__(self):
        list = []
        str1 = '新疆：乌鲁木齐、克拉玛依、石河子、阿拉尔市、图木舒克、巴音郭楞、伊宁市、五家渠、哈密、吐鲁番、阿克苏、喀什、和田、伊宁、塔城、阿勒泰、奎屯、博乐市、昌吉、阜康、库尔勒、阿图什市、乌苏'
        str2 = '西藏：拉萨、日喀则'
        str3 = '宁夏：银川、石嘴山、吴忠、固原、中卫、青铜峡市、灵武市'
        str4 = '内蒙古：呼和浩特、包头、乌海、巴彦淖尔市、赤峰、通辽、鄂尔多斯、呼伦贝尔、巴彦淖尔、乌兰察布、霍林郭勒市、海拉尔、满洲里市、牙克石市、扎兰屯市、根河市、额尔古纳市、丰镇市、锡林浩特市、二连浩特市、乌兰浩特市、阿尔山市'
        str5 = '广西：南宁、柳州、桂林、梧州、北海、崇左、来宾、贺州、玉林、百色、河池、钦州、防城港、贵港、岑溪市、凭祥、合山市、北流市、宜州市、东兴、桂平'
        str6 = '黑龙江：哈尔滨、大庆、齐齐哈尔、佳木斯、鸡西、鹤岗、双鸭山、牡丹江、伊春、七台河、黑河、绥化、五常、双城、尚志、纳河、虎林、密山市、铁力市、同江、富锦、绥芬河市、讷河、海林、宁安市、穆林、北安市、五大连池、肇东、海伦、安达'
        str7 = '吉林：长春、吉林、四平、辽源、通化、白山、松原、白城、九台市、榆树市、德惠市、舒兰市、桦甸市、安图县、蛟河市、磐石市、公主岭市、双辽市、梅河口市、集安市、临江市、大安市、洮南市、延吉市、图们市、敦化市、龙井市、珲春市、和龙市'
        str8 = "辽宁：沈阳、大连、鞍山、抚顺、本溪、丹东、锦州、营口、兴城市、阜新、辽阳、盘锦、铁岭、朝阳、葫芦岛、新民、瓦房店、普兰、庄河、海城、东港、凤城、凌海、北镇、大石桥、盖州、灯塔市、调兵山、开原、凌源、北票市、兴城"
        str9 = '河北：石家庄、唐山、邯郸、秦皇岛、保定、张家口、承德、廊坊、沧州、衡水、邢台、辛集市、藁城市、晋州市、赵县、新乐市、鹿泉市、遵化市、迁安市、武安市、南宫市、沙河市、涿州市、定州市、安国市、高碑店市、泊头市、任丘市、黄骅市、河间市、霸州市、三河市、冀州市、深州市'
        str10 = '山东：济南、青岛、淄博、枣庄、东营、烟台、潍坊、济宁、寿光、新泰、泰安、威海、日照、荣成市、莱芜、乳山市、临沂、德州、聊城、菏泽、滨州、章丘、胶南、胶州、平度、莱西、即墨、滕州、龙口、莱阳、莱州、招远、蓬莱、栖霞、海阳、青州、诸城、安丘、高密、昌邑、兖州、曲阜、邹城、乳山、文登、荣成、乐陵、临清、禹城'
        str11 = '江苏：南京、镇江、常州、无锡、苏州、沭阳、徐州、连云港、淮安、盐城、扬州、泰州、南通、沛县、如东县宿迁、江阴市、宜兴市、邳州市、新沂市、金坛市、溧阳市、常熟市、张家港市、太仓市、昆山市、吴江市、如皋市、通州市、海门市、启东市、东台市、大丰市、高邮市、江都市、仪征市、丹阳市、扬中市、句容市、泰兴市、姜堰市、靖江市、兴化市'
        str12 = '安徽：合肥、蚌埠、芜湖、淮南、亳州、阜阳、六安、淮北、宿州、滁州、霍邱、安庆、巢湖、马鞍山、宣城、黄山、池州、铜陵、界首市、天长、明光、桐城、宁国市'
        str13 = '浙江：杭州、嘉兴、湖州、宁波、金华、温州、丽水、绍兴、衢州、舟山、台州、建德市、富阳市、临安市、余姚市、慈溪市、奉化市、瑞安市、淳安县、德清县、横店、嘉善县、永嘉县、乐清市、海宁市、平湖市、桐乡市、诸暨市、上虞市、嵊州市、兰溪市、义乌市、东阳市、永康市、江山市、临海市、温岭市、龙泉市'
        str14 = '福建：福州、厦门、泉州、三明、南平、漳州、莆田、宁德、龙岩、福清市、长乐市、永安市、石狮市、晋江市、南安市、龙海市、邵武市、武夷山、建瓯市、建阳市、漳平市、福安市、福鼎市'
        str15 = '广东：广州、深圳、顺德、汕头、惠州、惠阳、珠海、雷州、揭阳、佛山、河源、阳江、茂名、湛江、梅州、肇庆、韶关、潮州、东莞、中山、清远、江门、汕尾、云浮、增城市、从化市、乐昌市、南雄市、台山市、开平市、鹤山市、恩平市、廉江市、雷州市 、吴川市、高州市、化州市、高要市、四会市、兴宁市、陆丰市、阳春市、英德市、连州市、普宁市、罗定市，信宜市'
        str16 = '海南：海口、三亚、琼海、文昌、万宁、五指山、儋州、东方'
        str17 = '云南：昆明、曲靖、玉溪、保山、昭通、丽江、德宏、普洱、临沧、文山、西双版纳、安宁市、宣威市、个旧市、开远市、景洪市、楚雄市、大理市、潞西市、瑞丽市'
        str18 = '贵州：贵阳、六盘水、遵义、安顺、清镇市、赤水市、仁怀市、铜仁市、毕节市、黔南、兴义市、凯里市、都匀市、福泉市'
        str19 = '四川：成都、绵阳、德阳、广元、自贡、攀枝花、乐山、凉山、南充、内江、遂宁、广安、泸州、双流区、达州、眉山、宜宾、雅安、资阳、都江堰市、彭州市、邛崃市、崇州市、广汉市、什邡市、绵竹市、江油市、峨眉山市、阆中市、华蓥市、万源市、简阳市、西昌市'
        str20 = '湖南：长沙、株洲、湘潭、衡阳、岳阳、郴州、永州、邵阳、怀化、常德、益阳、张家界、娄底、浏阳市、醴陵市、湘乡市、韶山市、耒阳市、常宁市、武冈市、临湘市、汨罗市、津市市、沅江市、资兴市、洪江市、冷水江市、涟源市、吉首市'
        str21 = '湖北：武汉、襄樊、宜昌、黄石、神农架、鄂州、随州、荆州、襄阳、荆门、十堰、孝感、黄冈、咸宁、大冶市、丹江口市、洪湖市、石首市、松滋市、宜都市、当阳市、枝江市、老河口市、枣阳市、宜城市、钟祥市、应城市、安陆市、汉川市、麻城市、武穴市、赤壁市、广水市、仙桃市、天门市、潜江市、恩施市、利川市'
        str22 = '河南：郑州、洛阳、开封、漯河、安阳、新乡、周口、三门峡、焦作、鄢陵、平顶山、信阳、南阳、鹤壁、濮阳、许昌、商丘、驻马店、巩义市、新郑市、新密市、登封市、荥阳市、偃师市、汝州市、舞钢市、林州市、卫辉市、辉县市、沁阳市、孟州市、禹州市、长葛市、义马市、灵宝市、邓州市、永城市、项城市、济源市'
        str23 = '山西：太原、大同、忻州、阳泉、长治、晋城、朔州、晋中、运城、临汾、临猗、清徐、侯马市、吕梁、古交、汾阳市、潞城市、高平、介休、永济市、河津、原平、侯马、霍州市、孝义'
        str24 = '陕西：西安、咸阳、铜川、延安、宝鸡、渭南、汉中、安康、商洛、榆林、兴平市、韩城市、华阴市'
        str25 = '甘肃：兰州、天水、平凉、酒泉、嘉峪关、金昌、白银、武威、张掖、庆阳、定西、陇南、玉门市、敦煌市、临夏市、合作市'
        str26 = '青海：西宁、格尔木市、德令哈市'
        str27 = '江西：南昌、九江、赣州、吉安、鹰潭、上饶、萍乡、景德镇、新余、宜春、抚州、乐平市、瑞昌市、贵溪市、瑞金市、玉山县、南康市、井冈山市、丰城市、樟树市、高安市、德兴市'
        str28 = '台湾：台北、台中、基隆、高雄、台南、新竹、嘉义、板桥市、宜兰市、竹北市、桃园市、苗栗市、丰原市、彰化市、南投市、太保市、斗六市、新营市、凤山市、屏东市、台东市、花莲市、马公市'
        str29 = '香港：香港'
        str30 = '澳门：澳门'
        str31 = '北京：北京市'
        str32 = '上海：上海市'
        str33 = '天津：天津市'
        str34 = '重庆：重庆市'
        list.append(str1)
        list.append(str2)
        list.append(str3)
        list.append(str4)
        list.append(str5)
        list.append(str6)
        list.append(str7)
        list.append(str8)
        list.append(str9)
        list.append(str10)
        list.append(str11)
        list.append(str12)
        list.append(str13)
        list.append(str14)
        list.append(str15)
        list.append(str16)
        list.append(str17)
        list.append(str18)
        list.append(str19)
        list.append(str20)
        list.append(str21)
        list.append(str22)
        list.append(str23)
        list.append(str24)
        list.append(str25)
        list.append(str26)
        list.append(str27)
        list.append(str28)
        list.append(str29)
        list.append(str30)
        list.append(str31)
        list.append(str32)
        list.append(str33)
        list.append(str34)
        self.list = list

    def Process(self, city):
        country = '中国'
        for i in range(0, 34):
            str = self.list[i]
            if city in str:
                if '：' in str:
                    province = str.split('：')[0];
                    ss = str.split('：')[1];
                    split = ss.split('、');
                    for j in range(len(split)):
                        s = split[j]
                        if city in s:
                            if city == s:
                                return country + ' ' + province + ' ' + split[j]
                            else:
                                ssss = s[:-1]
                                if city == ssss:
                                    return country + ' ' + province + ' ' + split[j]
        return ''

    def getProvince(self, city):
        str = self.Process(city)
        if str is not '':
            province = str.split(' ')[1]
            if ("北京" in province) or ("上海" in province) or ("重庆" in province) or ("天津" in province):
                province = province + "市"
            elif ("香港" in province) or ("澳门" in province):
                province = province + "特别行政区"
            elif ("内蒙古" in province) or ("宁夏" in province) or ("新疆" in province) or ("西藏" in province) or (
                    "广西" in province) or ("自治区" in province):
                if ("内蒙古" in province) or ("西藏" in province):
                    province = province + "自治区";
                if "宁夏" in province:
                    province = province + "回族自治区";
                if "新疆" in province:
                    province = province + "维吾尔自治区";
                if "广西" in province:
                    province = province + "壮族自治区";
            else:
                province = province + "省"
            return province
        return ''


if __name__ == '__main__':
    city = '新疆'
    s = ProcessInformation()
    province = s.getProvince(city)
    print(province)



#!/usr/bin/env python 
# coding=utf-8
# @Time : 2021/2/1 15:09 
# @Author : HL 
# @Site :  
# @File : Logger.py 
# @Software: PyCharm
import logging
import os
from logging import handlers

# class Logger(object):
#     level_relations = {
#         'debug': logging.DEBUG,
#         'info': logging.INFO,
#         'warning': logging.WARNING,
#         'error': logging.ERROR,
#         'crit': logging.CRITICAL
#     }  # 日志级别关系映射
#     datefmt = '%Y-%m-%d %H:%M:%S'
#
#     def __init__(self, filename, level='info', when='D', backCount=3,
#                  fmt='%(asctime)s - %(levelname)s - %(filename)s - %(funcName)s - %(lineno)s : %(message)s'):
#         self.logger = logging.getLogger(filename)
#         format_str = logging.Formatter(fmt, self.datefmt)  # 设置日志格式
#         self.logger.setLevel(self.level_relations.get(level))  # 设置日志级别
#         sh = logging.StreamHandler()  # 往屏幕上输出
#         sh.setFormatter(format_str)  # 设置屏幕上显示的格式
#         th = handlers.TimedRotatingFileHandler(filename=filename, when=when, backupCount=backCount,
#                                                encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
#         # 实例化TimedRotatingFileHandler
#         # interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
#         # S 秒
#         # M 分
#         # H 小时、
#         # D 天、
#         # W 每星期（interval==0时代表星期一）
#         # midnight 每天凌晨
#         th.setFormatter(format_str)  # 设置文件里写入的格式
#         self.logger.addHandler(sh)  # 把对象加到logger里
#         self.logger.addHandler(th)
from os.path import *


class Logger(object):
    level_relations = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'crit': logging.CRITICAL
    }  # 日志级别关系映射
    datefmt = '%Y-%m-%d %H:%M:%S'

    def __init__(self, path1, path2, level='info', when='D', backCount=3,
                 fmt='%(asctime)s - %(levelname)s - %(filename)s - %(funcName)s - %(lineno)s : %(message)s'):
        self.logger_info = logging.getLogger(path1)
        self.logger_error = logging.getLogger(path2)
        format_str = logging.Formatter(fmt, self.datefmt)  # 设置日志格式
        self.logger_info.setLevel(self.level_relations.get(level))  # 设置日志级别
        self.logger_error.setLevel(self.level_relations.get(level))  # 设置日志级别
        sh = logging.StreamHandler()  # 往屏幕上输出
        sh.setFormatter(format_str)  # 设置屏幕上显示的格式
        th1 = handlers.TimedRotatingFileHandler(filename=path1, when=when, backupCount=backCount,
                                                encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
        th2 = handlers.TimedRotatingFileHandler(filename=path2, when=when, backupCount=backCount,
                                                encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
        # 实例化TimedRotatingFileHandler
        # interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
        # S 秒
        # M 分
        # H 小时、
        # D 天、
        # W 每星期（interval==0时代表星期一）
        # midnight 每天凌晨
        th1.setFormatter(format_str)  # 设置文件里写入的格式
        th2.setFormatter(format_str)  # 设置文件里写入的格式
        self.logger_info.addHandler(sh)  # 把对象加到logger里
        self.logger_info.addHandler(th1)
        self.logger_error.addHandler(sh)  # 把对象加到logger里
        self.logger_error.addHandler(th2)


# if __name__ == '__main__':
    # log = Logger('all.log', level='debug')
    # log.logger.debug('debug')
    # log.logger.info('info')
    # log.logger.warning('警告')
    # log.logger.error('报错')
    # log.logger.critical('严重')

    # abpath = dirname(abspath(__file__))
    # path1 = os.path.join(abpath, 'logs/info.log')
    # path2 = os.path.join(abpath, 'logs/error.log')
    # log = Logger(path1, path2, level='info')
    # log.logger_error.debug('debug')
    # log.logger_error.info('info')
    # log.logger_error.warning('警告')
    # log.logger_info.error('报错')
    # log.logger_error.critical('严重')



#!/usr/bin/env python 
# coding=utf-8
# @Time : 2020/9/24 10:00 
# @Author : HL 
# @Site :  
# @File : DatabaseMogo.py 
# @Software: PyCharm
from pymongo import MongoClient


class Mongo_DB(object):

    def __init__(self, database, collection):
        self.client = MongoClient('192.168.0.139', 27017)
        self.db = self.client[database][collection]

    def add_one(self, post):
        '''新增数据'''
        return self.db.VehicleConfigParam.insert_one(post)

    def add_many(self, infos):
        '''新增多条数据'''
        # infos = [
        #     {'name': 'ben', 'age': 18, 'sex': "male", 'grade': 80, 'adress': "china"},
        #     {'name': 'sum', 'age': 19, 'sex': "male", 'grade': 75, 'adress': "china"}
        # ]
        return self.db.VehicleConfigParam.insert_many(infos)

    def get_one(self):
        '''查询一条数据'''
        return self.db.VehicleConfigParam.find_one()

    def get_more(self, condition):
        '''查询多条数据'''
        return self.db.find(condition)
    def get_mores(self):
        '''查询多条数据'''
        return self.db.find()

    def get_one_from_oid(self, obj):
        '''查询指定ID的数据'''
        # obj = ObjectId(oid)
        return self.db.VehicleConfigParam.find_one(obj)

    def save_no_repeat(self, condition, data):
        self.db.update_one(condition, {'$set': data}, True)

    def is_exist(self, obj):
        # python中mongodb判断某字段的值是否存在
        count = self.db.count_documents(obj)
        return count

    def update_one(self):
        '''修改一条数据'''
        return self.db.VehicleConfigParam.update_one({'age': 20}, {'$inc': {'x': 10}})

    def update_many(self):
        '''修改多条数据'''
        return self.db.VehicleConfigParam.update_many({}, {'$inc': {'age': 5}})

    def dalete_one(self, obj):
        '''删除一条数据'''
        return self.db.VehicleConfigParam.delete_one(obj)

    def delete_many(self, obj):
        '''删除多条数据'''
        return self.db.VehicleConfigParam.delete_many(obj)

    def crawl(self):
        # s = self.db.VehicleConfigParam.insert_many([{'name': '18', 'price': 100}])
        # print(s)
        data = {'name': '12', 'price': 245}
        self.db.update({'name': '12'}, {'$set': data}, True)

# if __name__ == '__main__':
#     # Mongo_DB('caximofan','VehicleConfigParam').crawl()
#     s = Mongo_DB('caximofan', 'Bidding').get_mores()
#     for x in s:
#         print(x)



#!/usr/bin/env python 
# coding=utf-8
# @Time : 2021/2/5 10:41 
# @Author : HL 
# @Site :  
# @File : setup.py.py 
# @Software: PyCharm
# coding=utf-8

from setuptools import setup, find_packages

with open("README.md", "r") as fh:  # 这里就是读取readme文件的内容了。
    long_description = fh.read()

setup(
    name='hcrawl',
    # '库的名称,一般写成文件夹的名字就可以了，也有的人不写成文件夹的名字，那么pip install和具体的import使用时候就不一样了，用起来会十分蛋疼，有一些包就是这样的。比如一个包，安装时候是pip install  xxx,但当你要使用时候要import yyy
    version="0.1.8",  # 版本，每次发版本都不能重复，每次发版必须改这个地方
    description=(
        'A daily tool for crawlers'  # 一个简介，别人搜索包时候，这个概要信息会显示在在搜索列表中
    ),
    long_description=open('README.md', 'r').read(),  # 这是详细的，一般是交别人怎么用，很多包没写，那么在官网就造成没有使用介绍了
    long_description_content_type="text/markdown",
    author='he525163',  # 作者
    author_email='hel_1226@sina.com',
    # maintainer='hl',     # 主要的工作人员
    # maintainer_email='909686719@qq.com',
    license='HL License',
    # packages=['hcrawl'], # 发布的包名
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/hchl9294',  # 这个是连接，一般写github就可以了，会从pypi跳转到这里去
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries'
    ],
    install_requires=[  # 这里是依赖列表，表示运行这个包的运行某些功能还需要你安装其他的包
        'pymongo', 'selenium', 'xlrd', 'requests', 'PyMySQL', 'beautifulsoup4'
    ]
)
